@@ -1,5 +1,4 @@
-from clean_architecture_basic_classes.basic_domain.task_scheduler_port import \
-    TaskSchedulerPort
+from clean_architecture_basic_classes.basic_domain.task_scheduler_port import TaskSchedulerPort
 from pytest import fixture
 from unittest.mock import MagicMock
 
@@ -18,10 +17,8 @@ def consumer_factory():
 
 def test_task_scheduler_port(consumer_factory):
     consumer = consumer_factory()
-
     assert consumer.scheduler_adapter is None
 
     mock_adapter = MagicMock()
     consumer.set_scheduler_adapter(mock_adapter)
-
     assert consumer.scheduler_adapter == mock_adapter
